@@ -28,7 +28,7 @@ TRIBUNE_MESSAGES_UA_COOKIE_MAXAGE = getattr(settings, 'SESSION_COOKIE_AGE', (60
 TRIBUNE_MESSAGES_UA_LENGTH_MIN = getattr(settings, 'TRIBUNE_MESSAGES_UA_LENGTH_MIN', 3)
 
 # Template string for smileys URL, this is where you can set the wanted smiley host
-TRIBUNE_SMILEYS_URL = getattr(settings, 'TRIBUNE_SMILEYS_URL', 'http://sfw.totoz.eu/{0}.gif')
+TRIBUNE_SMILEYS_URL = getattr(settings, 'TRIBUNE_SMILEYS_URL', 'http://totoz.eu/{0}.gif')
 
 # Name for session part containing the BaK
 TRIBUNE_BAK_SESSION_NAME = getattr(settings, 'TRIBUNE_BAK_SESSION_NAME', 'djangotribune_bak')
@@ -39,6 +39,9 @@ TRIBUNE_SESSION_MAX_OWNED_IDS = getattr(settings, 'TRIBUNE_SESSION_MAX_OWNED_IDS
 # How many urls maximum will be saved in a message
 TRIBUNE_SAVE_URLS_BY_POST = getattr(settings, 'TRIBUNE_SAVE_URLS_BY_POST', 5)
 
+# How many urls to list by page in the archives
+TRIBUNE_ARCHIVE_URLS_MAX_LIMIT = getattr(settings, 'TRIBUNE_ARCHIVE_URLS_MAX_LIMIT', 30)
+
 # Titles randomly displayed on tribune board (html and plain/text versions)
 TRIBUNE_TITLES = getattr(settings, 'TRIBUNE_TITLES_AVAILABLE', (
     u'Avengers Mansion', # Marvel Comics
